@@ -412,6 +412,11 @@ class FixtureDecoratorFactory(object):
 
     scope_class_map = defaultdict(lambda: TerraformFixture)
 
+    # Make accessing teardown options easier for users
+    TEARDOWN_IGNORE = td.IGNORE
+    TEARDOWN_OFF = td.OFF
+    TEARDOWN_ON = td.ON
+
     def __init__(self):
         self._fixtures = []
 
@@ -471,6 +476,7 @@ class FixtureDecoratorFactory(object):
 
     @staticmethod
     def nonce_decorator(func):
+        pytest.mark.terraform(func)
         return func
 
 
